@@ -9,8 +9,6 @@ from langchain_compass.openapi_tool_maker import make_tools
 
 
 class LangchainCompassToolkit(BaseToolkit):
-    # TODO: Replace all TODOs in docstring. See example docstring:
-    # https://github.com/langchain-ai/langchain/blob/c123cb2b304f52ab65db4714eeec46af69a861ec/libs/community/langchain_community/agent_toolkits/sql/toolkit.py#L19
     """LangchainCompass toolkit."""  # noqa: E501
 
     api_key: Optional[str] = Field(default=None, alias="compass_api_key")
@@ -22,13 +20,15 @@ class LangchainCompassToolkit(BaseToolkit):
         default=True,
         description="Whether to directly return the raw API response of "
         "POST requests to Compass API. If `False`, the agent"
-        "will summarize the response in words. `POST` requests are typically on-chain transactions.",
+        "will summarize the response in words. `POST` requests are typically"
+        "on-chain transactions.",
     )
     direct_return_read: bool = Field(
         default=False,
         description="Whether to directory return the raw API response of"
         "GET requests to Compass API. If `False`, the agent"
-        "will summarize the response in words. `GET` requests are typically data reads from chain, such as yield rates.",
+        "will summarize the response in words. `GET` requests are typically "
+        "data reads from chain, such as yield rates.",
     )
 
     def __init__(
